@@ -9,6 +9,7 @@ class QNMSettings(QtCore.QSettings):
 
 		self.groupMain = "main"
 		self.key_language = "language"
+		self.key_orientation = "orientation"
 
 		self.groupMonitorOpt = "monitor"
 		self.key_graphType = "graph_type"
@@ -364,3 +365,15 @@ class QNMSettings(QtCore.QSettings):
 		self.endGroup()
 		val = val.toString()
 		return val
+	
+	def setOrientation(self, orient):
+		self.beginGroup( self.groupMain )
+		self.setValue(self.key_orientation, orient)
+		self.endGroup()
+
+	def orientation(self):
+		self.beginGroup( self.groupMain )
+		val = self.value( self.key_orientation, "L" )
+		self.endGroup()
+		val = val.toString()
+		return val
