@@ -14,7 +14,7 @@ from sys import path
 from MyNotify import MyNotify
 
 from MyGraphicsScene import MyGraphicsScene
-import ViewSessionOptions
+import ViewSessionOptionsExt
 import DialogCommentExt
 
 class ViewSessionExt( QtGui.QMainWindow ):
@@ -26,7 +26,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		
 		try:
 			self.setAttribute( QtCore.Qt.WA_Maemo5StackedWindow )
-			self.setAttribute( QtCore.Qt.WA_Maemo5ShowProgressIndicator )
+			#self.setAttribute( QtCore.Qt.WA_Maemo5ShowProgressIndicator )
 		except Exception, e:
 			pass
 			#print "ViewSessionExt::__init__(): Exception setAttribute(): ",e
@@ -41,7 +41,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 
 		#геомертические параметры отображаемого графика
 		self.lengthX = 770
-		self.lengthY = 220
+		self.lengthY = 210
 		self.shiftX = 0
 		self.shiftY = 10
 		
@@ -139,22 +139,14 @@ class ViewSessionExt( QtGui.QMainWindow ):
 			self.ui.pBzoomIn.setEnabled( True )
 			self.ui.pBzoomOut.setEnabled( True )
 		
-		self.ui.wWait.setWindowOpacity(0.45)
-		self.ui.wWait.hide()
-
-		self.listLBL.append( self.ui.lbl_v1 )
-		self.listLBL.append( self.ui.lbl_v2 )
-		self.listLBL.append( self.ui.lbl_v3 )
-		self.listLBL.append( self.ui.lbl_v4 )
-		self.listLBL.append( self.ui.lbl_v5 )
-
 		#self.ui.graphicsView.setDragMode( QtGui.QGraphicsView.RubberBandDrag )
 		self.ui.graphicsView.setDragMode( QtGui.QGraphicsView.ScrollHandDrag )
 		#qaks = QtGui.QAbstractKineticScroller()
 		
-		self.dlgMO = QtGui.QDialog()
-		self.ui_dlgMO = ViewSessionOptions.Ui_DialogSessionOptions( )
-		self.ui_dlgMO.setupUi( self.dlgMO )
+		self.dlgMO = QtGui.QDialog( self )
+		#self.ui_dlgMO = ViewSessionOptions.Ui_DialogSessionOptions( )
+		#self.ui_dlgMO.setupUi( self.dlgMO )
+		self.ui_dlgMO = ViewSessionOptionsExt.ViewSessionOptionsExt( self.dlgMO )
 
 		self.ui_dlgMO.cbRuler.stateChanged.connect( self.changeViewMarker )
 		self.ui_dlgMO.pbTraffRX.toggled.connect( self.changeShowRX )
@@ -163,6 +155,47 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		
 		self.ui_dlgMO.bGrGraphType.buttonPressed.connect( self.changeGrT )
 
+		self.ui.widgetLegend.setParent(self.ui.graphicsView)
+		QtCore.QObject.connect( QtGui.QApplication.desktop(), QtCore.SIGNAL("resized(int)"), self.orientationChanged )
+
+
+
+	def wdgLabels(self):
+		self.wLabels = QtGui.QWidget(self.ui.graphicsView)
+		self.wLabels.setGeometry(QtCore.QRect(0, 0, 60, 220))
+
+		font = QtGui.QFont()
+		font.setPointSize(9)
+
+		self.lbl_v1 = QtGui.QLabel(self.wLabels)
+		self.lbl_v1.setGeometry(QtCore.QRect(10, 200, 50, 16))
+		self.lbl_v1.setFont(font)
+
+		self.lbl_v2 = QtGui.QLabel(self.wLabels)
+		self.lbl_v2.setGeometry(QtCore.QRect(10, 160, 50, 16))
+		self.lbl_v2.setFont(font)
+
+		self.lbl_v3 = QtGui.QLabel(self.wLabels)
+		self.lbl_v3.setGeometry(QtCore.QRect(10, 110, 50, 16))
+		self.lbl_v3.setFont(font)
+
+		self.lbl_v4 = QtGui.QLabel(self.wLabels)
+		self.lbl_v4.setGeometry(QtCore.QRect(10, 60, 50, 16))
+		self.lbl_v4.setFont(font)
+
+		self.lbl_v5 = QtGui.QLabel(self.wLabels)
+		self.lbl_v5.setGeometry(QtCore.QRect(10, 10, 50, 16))
+		self.lbl_v5.setFont(font)
+
+		self.wLabels.show()
+
+		self.listLBL.append( self.lbl_v1 )
+		self.listLBL.append( self.lbl_v2 )
+		self.listLBL.append( self.lbl_v3 )
+		self.listLBL.append( self.lbl_v4 )
+		self.listLBL.append( self.lbl_v5 )
+
+
 
 	def setTimeSession(self, allSeconds, hour, min, sec):
 		self.allSec_t = allSeconds
@@ -170,6 +203,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.m_t = min
 		self.s_t = sec
 
+
 	def showData(self):
 		#отображаем время сессии на форме
 		len_buf_data = len( self.buffSessionTraff )
@@ -235,13 +269,17 @@ class ViewSessionExt( QtGui.QMainWindow ):
 			self.ui.lblAllTraffValue.setText( "%.2f kB"%(sumBytes/1024.0) )
 		else:
 			self.ui.lblAllTraffValue.setText( "%s B"%(sumBytes) )
+		
+		self.wdgLabels()
 
 		#рисуем график
-		self.drawGraph()
+		#self.drawGraph()
+		self.orientationChanged()
 
 		self.ui.menubar.setEnabled( False )
 		self.ui.menubar.hide()
 
+
 	def drawGrid(self, maxScaleY):
 		pen = QtGui.QPen( QtGui.QColor(170,170,170) )
 		pen.setWidth(1)
@@ -282,7 +320,8 @@ class ViewSessionExt( QtGui.QMainWindow ):
 			it += 1
 
 		#self.scene.update()
-	
+
+
 	def drawSystemCoord(self):
 		pen = QtGui.QPen( QtGui.QColor(100,100,100) )
 		pen.setWidth(4)
@@ -290,11 +329,11 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.scene.addLine(self.shiftX, self.lengthY-self.shiftY, self.Lx, self.lengthY-self.shiftY, pen) #X - time
 		self.scene.addLine(self.shiftX, self.shiftX, self.shiftX, self.lengthY-self.shiftX, pen) #Y - Bytes
 
+
 	def drawGraph(self):
 
 		#рисуем текст "Rendering..." на графике
 		#self.ui.lblWait.show()
-		self.ui.wWait.show()
 
 		self.calcTimeScale()
 
@@ -462,13 +501,14 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.scene.update()
 		#self.ui.graphicsView.centerOn(x,0)
 		#self.ui.lblWait.hide()
-		self.ui.wWait.hide()
+
 
 	def changeShowRX(self, state):
 		self.showRX = state
 		self.qset.showRXSession( state )
 		self.drawGraph()
 
+
 	def changeShowTX(self, state):
 		self.showTX = state
 		self.qset.showTXSession( state )
@@ -516,6 +556,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 			self.drawGraph()
 			self.qset.setZoomSession( self.timeScale )
 
+
 	def zoomOut(self):
 		self.timeScale = self.timeScale*2
 		self.drawGraph()
@@ -636,7 +677,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 	
 	#------- Dialog comment ----------#
 	def dlgComment(self):
-		self.dlgCom = QtGui.QDialog()
+		self.dlgCom = QtGui.QDialog( self )
 		self.ui_dlgCom = DialogCommentExt.DialogCommentExt( self.dlgCom, self.db, self.session_id )
 		self.ui_dlgCom.commentAdd.connect( self.slotAddComment )
 		self.ui_dlgCom.commentDel.connect( self.slotDelComment )
@@ -644,14 +685,69 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.dlgCom.show()
 		self.dlgCom.exec_()
 
+
 	def slotAddComment( self ):
 		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment on the session is saved", None, QtGui.QApplication.UnicodeUTF8)
 		self.noti.notify( "%s"%txt )
 
+
 	def slotDelComment( self ):
 		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment on the session is removed", None, QtGui.QApplication.UnicodeUTF8)
 		self.noti.notify( "%s"%txt )
-	
+
+
 	def slotFailComment( self ):
 		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment write error", None, QtGui.QApplication.UnicodeUTF8)
 		self.noti.notify( "%s"%txt )
+	
+	
+	def orientationChanged( self ):
+			
+		self.ui.gridLayout.removeWidget( self.ui.graphicsView )
+		self.ui.gridLayout.removeItem( self.ui.vL_labels )
+		self.ui.gridLayout.removeItem( self.ui.vL_buttons )
+
+		o = StatistData.checkOrientation()
+		if o == "L":
+			# landscape
+			self.ui.gridLayout.addWidget( self.ui.graphicsView, 0, 0, 1, 2 )
+			self.ui.gridLayout.addItem( self.ui.vL_labels, 1, 0, 1, 1 )
+			self.ui.gridLayout.addItem( self.ui.vL_buttons, 1, 1, 1, 1 )
+
+			self.ui.widgetLegend.move( 640, 10 )
+
+			self.lengthX = 770
+			self.lengthY = 210
+
+			self.wLabels.setGeometry(QtCore.QRect(0, 0, 60, 220))
+			self.lbl_v1.setGeometry(QtCore.QRect(10, 205, 50, 16))
+			self.lbl_v2.setGeometry(QtCore.QRect(10, 160, 50, 16))
+			self.lbl_v3.setGeometry(QtCore.QRect(10, 110, 50, 16))
+			self.lbl_v4.setGeometry(QtCore.QRect(10, 60, 50, 16))
+			self.lbl_v5.setGeometry(QtCore.QRect(10, 10, 50, 16))
+		else:
+			# portait
+			self.ui.gridLayout.addWidget( self.ui.graphicsView, 0, 0, 1, 1 )
+			self.ui.gridLayout.addItem( self.ui.vL_labels, 1, 0, 1, 1 )
+			self.ui.gridLayout.addItem( self.ui.vL_buttons, 2, 0, 1, 1 )
+
+			self.ui.widgetLegend.move( 300, 10 )
+
+			self.lengthX = 430
+			self.lengthY = 380
+		
+			self.wLabels.setGeometry(QtCore.QRect(0, 0, 60, 370))
+			self.lbl_v1.setGeometry(QtCore.QRect(10, 355, 50, 16))
+			self.lbl_v2.setGeometry(QtCore.QRect(10, 285, 50, 16))
+			self.lbl_v3.setGeometry(QtCore.QRect(10, 190, 50, 16))
+			self.lbl_v4.setGeometry(QtCore.QRect(10, 100, 50, 16))
+			self.lbl_v5.setGeometry(QtCore.QRect(10, 10, 50, 16))
+
+		#вспомогательные переменные
+		#длина графика по оси Y
+		self.Ly = self.lengthY-self.shiftY
+		#длина графика по оси X
+		self.Lx = self.lengthX-self.shiftX
+
+		self.ui.graphicsView.setSceneRect(0, 0, self.lengthX, self.lengthY)
+		self.drawGraph()
